%global major 0
%define libname %mklibname bcc %major
%define devname %mklibname -d bcc

# luajit is not available for some architectures
%ifarch ppc64 ppc64le s390x
%bcond_with lua
%else
%bcond_without lua
%endif

%define srcname bcc

%bcond_with llvm_static

%if %{without llvm_static}
%global with_llvm_shared 1
%endif

# Force out of source build
%undefine __cmake_in_source_build

Name:           bcc
Version:        0.18.0
Release:        %mkrel 1
Summary:        BPF Compiler Collection (BCC)
Group:		Development/Kernel
License:        ASL 2.0
URL:            https://github.com/iovisor/bcc
# Upstream now provides a release with the git submodule embedded in it
Source0:        %{url}/releases/download/v%{version}/%{name}-src-with-submodule.tar.gz
#Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz

Patch0:         %{name}-0.15.0-Reinstate-bpf_detach_kfunc.patch

Patch11:        0001-cmake-always-link-to-packaged-libbpf-if-CMAKE_USE_LI.patch
Patch12:        0002-Remove-libbcc-no-libbpf-shared-library-change-libbcc.patch

# Arches will be included as upstream support is added and dependencies are
# satisfied in the respective arches
ExclusiveArch:  x86_64 %{power64} aarch64 s390x armv7hl

BuildRequires:  bison
BuildRequires:  cmake >= 2.8.7
BuildRequires:  flex
BuildRequires:  libxml2-devel
BuildRequires:  python3-devel
BuildRequires:  elfutils-devel
BuildRequires:  llvm-devel
BuildRequires:  clang-devel
%if %{with llvm_static}
BuildRequires:  llvm-static
%endif
BuildRequires:  ncurses-devel
%if %{with lua}
BuildRequires:  luajit
BuildRequires:  pkgconfig(luajit)
%endif
BuildRequires:  pkgconfig(libbpf) >= 0.0.5

Requires:       %{name}-tools = %{version}-%{release}
#Requires:       libbpf >= 0.0.5-3

%description
BCC is a toolkit for creating efficient kernel tracing and manipulation
programs, and includes several useful tools and examples. It makes use of
extended BPF (Berkeley Packet Filters), formally known as eBPF, a new feature
that was first added to Linux 3.15. BCC makes BPF programs easier to write,
with kernel instrumentation in C (and includes a C wrapper around LLVM), and
front-ends in Python and lua. It is suited for many tasks, including
performance analysis and network traffic control.


%package -n %libname
Summary: Shared library for BPF Compiler Collection (BCC)
Group: System/Libraries

%description -n %libname
Libary for BCC.

%package -n %devname
Group: Development/C
Summary:        Development files for BPF Compiler Collection (BCC)
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n %devname
The %{name}-devel package contains libraries and header files for developing
application that use BPF Compiler Collection (BCC).


%package doc
Summary:        Examples for BPF Compiler Collection (BCC)
Group:		Documentation
Recommends:     python3-%{name} = %{version}-%{release}
Recommends:     %{name}-lua = %{version}-%{release}
BuildArch:      noarch

%description doc
Examples for BPF Compiler Collection (BCC)


%package -n python3-%{name}
Summary:        Python3 bindings for BPF Compiler Collection (BCC)
Group:		Development/Python
Requires:       %{libname} = %{version}-%{release}
%{?python_provide:%python_provide python3-%{srcname}}

%description -n python3-%{name}
Python3 bindings for BPF Compiler Collection (BCC)


%if %{with lua}
%package lua
Summary:        Standalone tool to run BCC tracers written in Lua
Group:		Development/Kernel
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description lua
Standalone tool to run BCC tracers written in Lua
%endif


%package tools
Summary:        Command line tools for BPF Compiler Collection (BCC)
Group:		Development/Kernel
Requires:       python3-%{name} = %{version}-%{release}
Requires:       python3-netaddr
Requires:       kernel-devel

%description tools
Command line tools for BPF Compiler Collection (BCC)


%prep
%autosetup -p1 -n %{name}


%build
%cmake . \
        -DCMAKE_BUILD_TYPE=RelWithDebInfo \
        -DREVISION_LAST=%{version} -DREVISION=%{version} -DPYTHON_CMD=python3 \
        -DCMAKE_USE_LIBBPF_PACKAGE:BOOL=TRUE \
        %{?with_llvm_shared:-DENABLE_LLVM_SHARED=1}
%cmake_build || %cmake_build


%install
%cmake_install

# Fix python shebangs
find %{buildroot}%{_datadir}/%{name}/{tools,examples} -type f -exec \
  sed -i -e '1s=^#!/usr/bin/python\([0-9.]\+\)\?$=#!%{__python3}=' \
         -e '1s=^#!/usr/bin/env python\([0-9.]\+\)\?$=#!%{__python3}=' \
         -e '1s=^#!/usr/bin/env bcc-lua$=#!/usr/bin/bcc-lua=' {} \;

# Move man pages to the right location
mkdir -p %{buildroot}%{_mandir}
mv %{buildroot}%{_datadir}/%{name}/man/* %{buildroot}%{_mandir}/
# Avoid conflict with other manpages
# https://bugzilla.redhat.com/show_bug.cgi?id=1517408
for i in `find %{buildroot}%{_mandir} -name "*.gz"`; do
  tname=$(basename $i)
  rename $tname %{name}-$tname $i
done
mkdir -p %{buildroot}%{_docdir}/%{name}
mv %{buildroot}%{_datadir}/%{name}/examples %{buildroot}%{_docdir}/%{name}/

# Delete old tools we don't want to ship
rm -rf %{buildroot}%{_datadir}/%{name}/tools/old/

# We cannot run the test suit since it requires root and it makes changes to
# the machine (e.g, IP address)
#%check


%files -n %libname
%doc README.md
%license LICENSE.txt
%{_libdir}/lib%{name}.so.%{major}{,.*}
%{_libdir}/libbcc_bpf.so.%{major}{,.*}

%files -n %devname
%exclude %{_libdir}/lib%{name}*.a
%{_libdir}/lib%{name}.so
%{_libdir}/libbcc_bpf.so
%{_libdir}/pkgconfig/lib%{name}.pc
%{_includedir}/%{name}/

%files -n python3-%{name}
%{python3_sitelib}/%{name}*

%files doc
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/examples/

%files tools
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/tools/
%{_datadir}/%{name}/introspection/
%{_mandir}/man8/*

%if %{with lua}
%files lua
%{_bindir}/bcc-lua
%endif



%changelog
* Sat Jan 16 2021 wally <wally> 0.18.0-1.mga8
+ Revision: 1671988
- add patches from upstream to fix build
- remove unneeded linking fixes
+ tv <tv>
- 0.18.0

* Thu Nov 26 2020 tv <tv> 0.17.0-3.mga8
+ Revision: 1649610
- rebuild for llvm

* Mon Nov 02 2020 pterjan <pterjan> 0.17.0-2.mga8
+ Revision: 1641827
- Add upstream patch to only run test_usdt_args on supported architectures

* Fri Oct 30 2020 tv <tv> 0.17.0-1.mga8
+ Revision: 1640612
- 0.17.0

* Sat Sep 26 2020 pterjan <pterjan> 0.16.0-4.mga8
+ Revision: 1630613
- Make the python package not noarch as it requires arch specific package name (libname) so can not be installed on either 32 or 64 architectures depending where it was built
- Drop incorrect workaround preventing from building on 32 bits architectures

* Thu Sep 17 2020 tv <tv> 0.16.0-2.mga8
+ Revision: 1628004
- Enable build for armv7hl

* Mon Aug 24 2020 tv <tv> 0.16.0-1.mga8
+ Revision: 1618549
- 0.16.0

* Sat Aug 22 2020 tv <tv> 0.15.0-3.mga8
+ Revision: 1617904
- make python subpkg noarch

* Wed Jul 15 2020 tv <tv> 0.15.0-2.mga8
+ Revision: 1606362
- Reinstate a function needed by bpftrace
- really update to 0.15 tarball
- Drop llvm-static dependency
- https://docs.fedoraproject.org/en-US/packaging-guidelines/#_statically_linking_executables

* Tue Jun 23 2020 tv <tv> 0.15.0-1.mga8
+ Revision: 1598670
- 0.15.0

* Thu May 07 2020 tv <tv> 0.14.0-1.mga8
+ Revision: 1581534
- 0.14.0

* Sun Mar 22 2020 tv <tv> 0.13.0-3.mga8
+ Revision: 1558890
- rebuild for llvm-10.0.0

* Thu Mar 12 2020 tv <tv> 0.13.0-2.mga8
+ Revision: 1555823
- our kernel doesn't build libpf on aarch64...
- fix more shebangs
- new release
- run make if make -j fails
- link against libclang-cpp.so
- workaround buggy libbpf-devel not pulling  libbpf0
- New release
- Add libbpf support
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Fri Dec 27 2019 wally <wally> 0.11.0-2.mga8
+ Revision: 1470242
- add patch to fix linking
- build with new cmake macros
- update summaries
- fix python shebangs with pathfix.py
- add lib major to file list

* Mon Oct 14 2019 tv <tv> 0.11.0-1.mga8
+ Revision: 1453030
- despite upstream claims, upstream tarball is still incomplete
- new release
- rebuild for clang-9.0

* Wed Sep 18 2019 tv <tv> 0.10.0-4.mga8
+ Revision: 1443438
- rebuild for clang-9.0

* Wed Sep 11 2019 tv <tv> 0.10.0-3.mga8
+ Revision: 1439764
- rebuild for python-3.8

* Fri Aug 09 2019 tv <tv> 0.10.0-2.mga8
+ Revision: 1428398
- python3 subpkg cannot be noarch as it requires libified lib subpkg

* Tue Jul 23 2019 tv <tv> 0.10.0-1.mga8
+ Revision: 1423593
- new release

* Thu May 09 2019 tv <tv> 0.9.0-1.mga7
+ Revision: 1396953
- new release
+ neoclust <neoclust>
- imported package bcc


* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Thu Mar 30 2017 Igor Gnatenko <ignatenko@redhat.com> - 0.3.0-2
- Rebuild for LLVM4
- Trivial fixes in spec

* Fri Mar 10 2017 Rafael Fonseca <rdossant@redhat.com> - 0.3.0-1
- Rebase to new release.

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jan 10 2017 Rafael Fonseca <rdossant@redhat.com> - 0.2.0-2
- Fix typo

* Tue Nov 29 2016 Rafael Fonseca <rdossant@redhat.com> - 0.2.0-1
- Initial import
